function S = cl2salin(mCl)

% CL2SALIN - calculates seawater salinity based on known Cl concentration
%
%     Usage: S = cl2salin(mCl)
%
%     Input parameters (scalar,vector or matrix):
%          mCl     - chloride concentration in seawater [mol/kg]
%
%     Output parameter: 
%           S      - practical salinity 
%
%     Comments: 
%     This script takes the true Cl-ion concentration as input.
%     To calculate practical salinity from chlorinity use: S = Cl*1.80655 
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (August 2009)
%               GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------

%------------------------------------------------------------------------
% Modification history: 
%       June 2010: Usage instruction included in header
%       September 2011: format information in header extended
%       February 2013:  equation corrected
%------------------------------------------------------------------------


%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 1
     warning('CL2SALIN:Input','CL2Salin: Missing input parameter! Please provide mCl!')
else
%------------------------------------------------------------------------
% Calculate salinity
%------------------------------------------------------------------------
REFS = 35;% reference salinity

S = mCl*REFS/0.5657647;    

end
