function m = molar2molal_sw(press,temp,sal,c)

% MOLAR2MOLAL_SW -  converts solute concentration in molarities [mol/l]
%      into molalities [mol/kg] for standard seawater composition
%
%      Usage: m = molar2molal_sw(p,T,S,c)
%
%       Input parameters (scalars or vectors):
%           p       - pressure [MPa] 
%           T       - temperature [degC] 
%           S       - practical salinity  
%           c       - molar concentration of salt component [mol/l]
%
%       Output parameter: 
%           m       - molal concentration of salt component [mol/kg]
%
% ------------------------------------------------------------------
%   written by: Elke Kossel, Matthias Haeckel (August 2009)
%               GEOMAR, Kiel, Germany
%   Disclaimer:
%   This software is provided "as is" without warranty of any kind.
% ------------------------------------------------------------------

% ------------------------------------------------------------------
%   Modification history: 
%       November 2012: syntax changed to Matlab2012 style
%                      typos in header corrected
% ------------------------------------------------------------------

%------------------------------------------------------------------------
% Check number of input parameters
%------------------------------------------------------------------------

if nargin < 4
     warning('MOLAR2MOLAL_SW:Input','MOLAR2MOLAL_SW: Missing input parameter! Please provide p,T,S and m!')
else

%------------------------------------------------------------------------
% Definition of constants and thermodynamic variables
%------------------------------------------------------------------------
[~,~,S,C] = ndgrid(press,temp,sal,c); 
rho = density_sw(press,temp,sal);

% resize matrix for rho to size of C
rho_2 = zeros(size(C));
for i = 1:size(C,4)
    rho_2(:,:,:,i) = rho;
end

%------------------------------------------------------------------------
% Calculate molalities  
%------------------------------------------------------------------------

m=C./((1-0.001005.*S).*rho_2./1000);

end